@@ -1,3 +1,9 @@
+//! # NOT MAINTAINED
+//! This crate was replaced by the [`fixed-buffer`](https://crates.io/crates/fixed-buffer)
+//! crate with `tokio` feature.
+//!
+//! ----
+//!
 //! [![crates.io version](https://img.shields.io/crates/v/fixed-buffer-tokio.svg)](https://crates.io/crates/fixed-buffer-tokio)
 //! [![license: Apache 2.0](https://gitlab.com/leonhard-llc/fixed-buffer-rs/-/raw/main/license-apache-2.0.svg)](http://www.apache.org/licenses/LICENSE-2.0)
 //! [![unsafe forbidden](https://gitlab.com/leonhard-llc/fixed-buffer-rs/-/raw/main/unsafe-forbidden-success.svg)](https://github.com/rust-secure-code/safety-dance/)
@@ -115,14 +121,14 @@ impl<const SIZE: usize> AsyncFixedBuf<SIZE> {
         &mut self,
         reader: &mut R,
     ) -> Result<usize, std::io::Error> {
-        let mut writable = self.writable();
+        let writable = self.writable();
         if writable.is_empty() {
             return Err(std::io::Error::new(
                 std::io::ErrorKind::InvalidData,
                 "no empty space in buffer",
             ));
         };
-        let num_read = tokio::io::AsyncReadExt::read(reader, &mut writable).await?;
+        let num_read = tokio::io::AsyncReadExt::read(reader, writable).await?;
         self.wrote(num_read);
         Ok(num_read)
     }
